@@ -3,6 +3,7 @@
 import re
 import datetime
 
+from .._compat import decode
 from .formatter import Formatter
 
 
@@ -316,7 +317,7 @@ class AlternativeFormatter(Formatter):
             # Defaulting to english
             return self._format_localizable_token(dt, token, 'en')
 
-        return trans
+        return decode(trans)
 
     def parse(self, time, fmt):
         """
@@ -330,6 +331,7 @@ class AlternativeFormatter(Formatter):
 
         :rtype: tuple
         """
+        fmt = re.escape(fmt)
         tokens = self._FORMAT_RE.findall(fmt)
         if not tokens:
             return time
@@ -397,7 +399,7 @@ class AlternativeFormatter(Formatter):
         if token.startswith('[') and token.endswith(']'):
             return token[1:-1]
         elif token.startswith('\\'):
-            return token[1:]
+            return token
         elif token not in self._REGEX_TOKENS:
             raise ValueError('Unsupported token: {}'.format(token))
 
